@@ -1,7 +1,7 @@
 /*
  *  deferdlg.cpp  -  dialog to defer an alarm
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -14,10 +14,9 @@
 #include "resourcescalendar.h"
 #include "resources/resources.h"
 #include "lib/messagebox.h"
+#include "kalarmcalendar/kaevent.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/KAEvent>
-
 #include <KLocalizedString>
 
 #include <QVBoxLayout>
@@ -60,7 +59,7 @@ DeferAlarmDlg::DeferAlarmDlg(const DateTime& initialDT, bool anyTimeOption, bool
         QPushButton* deferButton = mButtonBox->addButton(i18nc("@action:button", "Cancel Deferral"), QDialogButtonBox::ActionRole);
         deferButton->setWhatsThis(i18nc("@info:whatsthis", "Cancel the deferred alarm. This does not affect future recurrences."));
         connect(mButtonBox, &QDialogButtonBox::clicked, this,
-                [this, deferButton](QAbstractButton* btn)
+                [this, deferButton](const QAbstractButton* btn)
                 {
                     if (btn == deferButton)
                         slotCancelDeferral();
