@@ -1,14 +1,14 @@
 /*
  *  displaycalendar.h  -  KAlarm display calendar file access
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kaevent.h"
 
 #include <KCalendarCore/FileStorage>
 #include <KCalendarCore/Event>
@@ -56,5 +56,4 @@ private:
     static bool                       mOpen;               // true if the calendar file is open
 };
 
-
 // vim: et sw=4:
