@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -40,15 +40,17 @@
 #include "lib/timeedit.h"
 #include "lib/timespinbox.h"
 #include "lib/timezonecombo.h"
+#include "kalarmcalendar/identities.h"
 #include "config-kalarm.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/Identities>
-
 #include <KHolidays/HolidayRegion>
 using namespace KHolidays;
 
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/TextToSpeech>
+#endif
 
 #include <KLocalizedString>
 #include <KShell>
@@ -687,8 +689,8 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     {
         const QString name = HolidayRegion::name(regionCode);
         const QString languageName = QLocale::languageToString(QLocale(HolidayRegion::languageCode(regionCode)).language());
-        const QString label = languageName.isEmpty() ? name : i18nc("Holiday region, region language", "%1 (%2)", name, languageName);
-        regionsMap.insert(label, regionCode);
+        const QString labelText = languageName.isEmpty() ? name : i18nc("Holiday region, region language", "%1 (%2)", name, languageName);
+        regionsMap.insert(labelText, regionCode);
     }
 
     mHolidays->addItem(i18nc("No holiday region", "None"), QString());
@@ -801,8 +803,8 @@ void TimePrefTab::restore(bool, bool)
 {
     KADateTime::Spec timeSpec = Preferences::timeSpec();
     mTimeZone->setTimeZone(timeSpec.type() == KADateTime::TimeZone ? timeSpec.timeZone() : QTimeZone());
-    const int i = Preferences::holidays().isValid() ? mHolidays->findData(Preferences::holidays().regionCode()) : 0;
-    mHolidays->setCurrentIndex(i);
+    const int ix = Preferences::holidays().isValid() ? mHolidays->findData(Preferences::holidays().regionCode()) : 0;
+    mHolidays->setCurrentIndex(ix);
     mStartOfDay->setValue(Preferences::startOfDay());
     mWorkStart->setValue(Preferences::workDayStart());
     mWorkEnd->setValue(Preferences::workDayEnd());
@@ -1010,7 +1012,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     mEmailCopyToKMail = new QCheckBox(xi18nc("@option:check", "Copy sent emails into <application>KMail</application>'s <resource>%1</resource> folder", KAMail::i18n_sent_mail()));
     mEmailCopyToKMail->setWhatsThis(xi18nc("@info:whatsthis", "After sending an email, store a copy in <application>KMail</application>'s <resource>%1</resource> folder", KAMail::i18n_sent_mail()));
     box->addWidget(mEmailCopyToKMail);
-    box->setStretchFactor(new QWidget(widget), 1);    // left adjust the controls
+    box->addStretch();    // left adjust the controls
 
     widget = new QWidget;   // this is to allow left adjustment
     topLayout()->addWidget(widget);
@@ -1020,7 +1022,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
           i18nc("@info:whatsthis", "Display a notification message whenever an email alarm has queued an email for sending to a remote system. "
                "This could be useful if, for example, you have a dial-up connection, so that you can then ensure that the email is actually transmitted."));
     box->addWidget(mEmailQueuedNotify);
-    box->setStretchFactor(new QWidget(widget), 1);    // left adjust the controls
+    box->addStretch();    // left adjust the controls
 
     // Your Email Address group box
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Your Email Address"));
@@ -1171,7 +1173,7 @@ QString EmailPrefTab::validate()
         mBccAddressChanged = false;
         return validateAddr(mBccAddressGroup, mEmailBccAddress, i18nc("@info", "No valid 'Bcc' email address is specified."));
     }
-    return QString();
+    return {};
 }
 
 QString EmailPrefTab::validateAddr(ButtonGroup* group, QLineEdit* addr, const QString& msg)
@@ -1181,17 +1183,17 @@ QString EmailPrefTab::validateAddr(ButtonGroup* group, QLineEdit* addr, const QS
     {
         case Preferences::MAIL_FROM_SYS_SETTINGS:
             if (!KAMail::controlCentreAddress().isEmpty())
-                return QString();
+                return {};
             errmsg = xi18nc("@info", "No default email address is currently set in <application>KMail</application> or KDE System Settings. %1", errmsg);
             break;
         case Preferences::MAIL_FROM_KMAIL:
             if (Identities::identitiesExist())
-                return QString();
+                return {};
             errmsg = xi18nc("@info", "No <application>KMail</application> identities currently exist. %1", errmsg);
             break;
         case Preferences::MAIL_FROM_ADDR:
             if (!addr->text().trimmed().isEmpty())
-                return QString();
+                return {};
             break;
     }
     return errmsg;
@@ -1355,8 +1357,10 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     mSound->addItem(SoundPicker::i18n_combo_None());         // index 0
     mSound->addItem(SoundPicker::i18n_combo_Beep());         // index 1
     mSound->addItem(SoundPicker::i18n_combo_File());         // index 2
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     if (KPIMTextEdit::TextToSpeech::self()->isReady())
-        mSound->addItem(SoundPicker::i18n_combo_Speak());  // index 3
+        mSound->addItem(SoundPicker::i18n_combo_Speak());    // index 3
+#endif
     mSound->setMinimumSize(mSound->sizeHint());
     mSound->setWhatsThis(defsetting.subs(SoundPicker::i18n_label_Sound()).toString());
     hlayout->addWidget(mSound);
@@ -1539,7 +1543,9 @@ void EditPrefTab::apply(bool syncToDisc)
     Preferences::SoundType snd;
     switch (mSound->currentIndex())
     {
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
         case 3:  snd = Preferences::Sound_Speak; break;
+#endif
         case 2:  snd = Preferences::Sound_File;  break;
         case 1:  snd = Preferences::Sound_Beep;  break;
         case 0:
@@ -1624,7 +1630,9 @@ int EditPrefTab::soundIndex(Preferences::SoundType type)
 {
     switch (type)
     {
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
         case Preferences::Sound_Speak: return 3;
+#endif
         case Preferences::Sound_File:  return 2;
         case Preferences::Sound_Beep:  return 1;
         case Preferences::Sound_None:
@@ -1639,7 +1647,7 @@ QString EditPrefTab::validate()
         mSoundFile->setFocus();
         return xi18nc("@info", "You must enter a sound file when <interface>%1</interface> is selected as the default sound type", SoundPicker::i18n_combo_File());;
     }
-    return QString();
+    return {};
 }
 
 
@@ -1677,7 +1685,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
         mShowInSystemTrayCheck = new QCheckBox(showInSysTrayText);
         mShowInSystemTrayCheck->setWhatsThis(showInSysTrayWhatsThis);
         box->addWidget(mShowInSystemTrayCheck);
-        box->setStretchFactor(new QWidget(widget), 1);    // left adjust the controls
+        box->addStretch();    // left adjust the controls
     }
     else
     {
@@ -1850,7 +1858,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     box->addWidget(mWindowButtonDelay);
     widget->setWhatsThis(i18nc("@info:whatsthis",
                             "Enter how long its buttons should remain disabled after the alarm message window is shown."));
-    box->setStretchFactor(new QWidget(widget), 1);    // left adjust the controls
+    box->addStretch();    // left adjust the controls
     grid->addWidget(widget, 2, 1, Qt::AlignLeft);
 
     if (KWindowSystem::isPlatformX11())
