@@ -1,7 +1,7 @@
 /*
  *  resourcedatamodelbase.cpp  -  base for models containing calendars and events
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2007-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -9,14 +9,12 @@
 #include "resourcedatamodelbase.h"
 
 #include "resources.h"
-
 #include "lib/desktop.h"
 #include "lib/messagebox.h"
+#include "kalarmcalendar/alarmtext.h"
+#include "kalarmcalendar/kaevent.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/AlarmText>
-#include <KAlarmCal/KAEvent>
-
 #include <KLocalizedString>
 
 #include <QApplication>
@@ -105,7 +103,7 @@ QVariant ResourceDataModelBase::headerData(int section, Qt::Orientation orientat
         {
             // Event column headers
             if (section < 0  ||  section >= ColumnCount)
-                return QVariant();
+                return {};
             if (role == Qt::DisplayRole  ||  role == ColumnTitleRole)
             {
                 switch (section)
@@ -135,14 +133,14 @@ QVariant ResourceDataModelBase::headerData(int section, Qt::Orientation orientat
         {
             // Calendar column headers
             if (section != 0)
-                return QVariant();
+                return {};
             if (role == Qt::DisplayRole)
                 return i18nc("@title:column", "Calendars");
         }
     }
 
     handled = false;
-    return QVariant();
+    return {};
 }
 
 /******************************************************************************
@@ -216,7 +214,7 @@ QVariant ResourceDataModelBase::resourceData(int& role, const Resource& resource
     }
 
     handled = false;
-    return QVariant();
+    return {};
 }
 
 /******************************************************************************
@@ -240,7 +238,7 @@ QVariant ResourceDataModelBase::eventData(int role, int column, const KAEvent& e
                 break;
         }
         if (!event.isValid())
-            return QVariant();
+            return {};
         switch (role)
         {
             case EventIdRole:
@@ -468,7 +466,7 @@ QVariant ResourceDataModelBase::eventData(int role, int column, const KAEvent& e
     }
 
     handled = false;
-    return QVariant();
+    return {};
 }
 
 /******************************************************************************
@@ -568,7 +566,7 @@ QString ResourceDataModelBase::whatsThisText(int column)
         case TemplateNameColumn:
             return i18nc("@info:whatsthis", "Name of the alarm template");
         default:
-            return QString();
+            return {};
     }
 }
 
@@ -721,10 +719,10 @@ QString ResourceDataModelBase::alarmTimeText(const DateTime& dateTime, char lead
             const QTime t(1,30,30);
             const QString nozero = locale.toString(t, timeFormat);
             const QString zero   = locale.toString(t, timeFullFormat);
-            for (int i = 0; i < nozero.size(); ++i)
-                if (nozero[i] != zero[i])
+            for (int j = 0; j < nozero.size(); ++j)
+                if (nozero[j] != zero[j])
                 {
-                    hourOffset = i;
+                    hourOffset = j;
                     break;
                 }
         }
@@ -766,7 +764,7 @@ QString ResourceDataModelBase::timeToAlarmText(const DateTime& dateTime)
     }
     const int mins = (now.secsTo(dateTime.effectiveKDateTime()) + 59) / 60;
     if (mins <= 0)
-        return QString();
+        return {};
     QLocale locale;
     QString minutes = locale.toString(mins % 60);
     if (minutes.size() == 1)
